@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -39,7 +40,7 @@ class NUEgressQOSPolicy(NURESTObject):
     """ Represents a EgressQOSPolicy in the VSD
 
         Notes:
-            The object manipulates Egress QoS parameters attached to a Access Port / VLAN or Network port.
+            An Egress QoS Policy is a policy that groups rate-limiting profiles, traffic directionality and classifiers to govern the rate of traffic being sent or received by an end-host or application.
     """
 
     __rest_name__ = "egressqospolicy"
@@ -179,7 +180,7 @@ class NUEgressQOSPolicy(NURESTObject):
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
-        self.expose_attribute(local_name="parent_queue_associated_rate_limiter_id", remote_name="parentQueueAssociatedRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="parent_queue_associated_rate_limiter_id", remote_name="parentQueueAssociatedRateLimiterID", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="default_service_class", remote_name="defaultServiceClass", attribute_type=str, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -192,7 +193,7 @@ class NUEgressQOSPolicy(NURESTObject):
         self.expose_attribute(local_name="queue2_associated_rate_limiter_id", remote_name="queue2AssociatedRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="queue2_forwarding_classes", remote_name="queue2ForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="queue3_associated_rate_limiter_id", remote_name="queue3AssociatedRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="queue3_forwarding_classes", remote_name="queue3ForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
+        self.expose_attribute(local_name="queue3_forwarding_classes", remote_name="queue3ForwardingClasses", attribute_type=list, is_required=True, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="queue4_associated_rate_limiter_id", remote_name="queue4AssociatedRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="queue4_forwarding_classes", remote_name="queue4ForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -239,7 +240,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get parent_queue_associated_rate_limiter_id value.
 
             Notes:
-                ID of the parent rate limiter associated with this Egress QOS policy.
+                ID of the parent rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `parentQueueAssociatedRateLimiterID` in VSD API.
@@ -252,7 +253,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set parent_queue_associated_rate_limiter_id value.
 
             Notes:
-                ID of the parent rate limiter associated with this Egress QOS policy.
+                ID of the parent rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `parentQueueAssociatedRateLimiterID` in VSD API.
@@ -424,7 +425,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get associated_dscp_remarking_policy_table_id value.
 
             Notes:
-                ID of the DSCP Remarking Policy Table associated with this Egress QOS policy.
+                ID of the DSCP Remarking Policy Table associated with this Egress QoS policy.
 
                 
                 This attribute is named `associatedDSCPRemarkingPolicyTableID` in VSD API.
@@ -437,7 +438,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set associated_dscp_remarking_policy_table_id value.
 
             Notes:
-                ID of the DSCP Remarking Policy Table associated with this Egress QOS policy.
+                ID of the DSCP Remarking Policy Table associated with this Egress QoS policy.
 
                 
                 This attribute is named `associatedDSCPRemarkingPolicyTableID` in VSD API.
@@ -451,7 +452,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue1_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue1 rate limiter associated with this Egress QOS policy.
+                ID of the queue1 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue1AssociatedRateLimiterID` in VSD API.
@@ -464,7 +465,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue1_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue1 rate limiter associated with this Egress QOS policy.
+                ID of the queue1 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue1AssociatedRateLimiterID` in VSD API.
@@ -478,7 +479,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue1_forwarding_classes value.
 
             Notes:
-                Queue1 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue1 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue1ForwardingClasses` in VSD API.
@@ -491,7 +492,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue1_forwarding_classes value.
 
             Notes:
-                Queue1 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue1 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue1ForwardingClasses` in VSD API.
@@ -505,7 +506,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue2_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue2 rate limiter associated with this Egress QOS policy.
+                ID of the queue2 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue2AssociatedRateLimiterID` in VSD API.
@@ -518,7 +519,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue2_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue2 rate limiter associated with this Egress QOS policy.
+                ID of the queue2 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue2AssociatedRateLimiterID` in VSD API.
@@ -532,7 +533,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue2_forwarding_classes value.
 
             Notes:
-                Queue2 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue2 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue2ForwardingClasses` in VSD API.
@@ -545,7 +546,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue2_forwarding_classes value.
 
             Notes:
-                Queue2 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue2 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue2ForwardingClasses` in VSD API.
@@ -559,7 +560,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue3_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue3 rate limiter associated with this Egress QOS policy.
+                ID of the queue3 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue3AssociatedRateLimiterID` in VSD API.
@@ -572,7 +573,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue3_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue3 rate limiter associated with this Egress QOS policy.
+                ID of the queue3 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue3AssociatedRateLimiterID` in VSD API.
@@ -586,7 +587,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue3_forwarding_classes value.
 
             Notes:
-                Queue3 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue3 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue3ForwardingClasses` in VSD API.
@@ -599,7 +600,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue3_forwarding_classes value.
 
             Notes:
-                Queue3 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue3 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue3ForwardingClasses` in VSD API.
@@ -613,7 +614,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue4_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue4 rate limiter associated with this Egress QOS policy.
+                ID of the queue4 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue4AssociatedRateLimiterID` in VSD API.
@@ -626,7 +627,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue4_associated_rate_limiter_id value.
 
             Notes:
-                ID of the queue4 rate limiter associated with this Egress QOS policy.
+                ID of the queue4 rate limiter associated with this Egress QoS policy.
 
                 
                 This attribute is named `queue4AssociatedRateLimiterID` in VSD API.
@@ -640,7 +641,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Get queue4_forwarding_classes value.
 
             Notes:
-                Queue4 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue4 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue4ForwardingClasses` in VSD API.
@@ -653,7 +654,7 @@ class NUEgressQOSPolicy(NURESTObject):
         """ Set queue4_forwarding_classes value.
 
             Notes:
-                Queue4 Forwarding Classes for this Egress QOS Policy Possible values are NONE, A, B, C, D, E, F, G, H, .
+                Queue4 Forwarding Classes for this Egress QoS Policy Possible values are NONE, A, B, C, D, E, F, G, H.
 
                 
                 This attribute is named `queue4ForwardingClasses` in VSD API.
