@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUPermissionsFetcher
 
 
@@ -74,8 +75,6 @@ class NUNSPort(NURESTObject):
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
-    CONST_SPEED_BASE10 = "BASE10"
-    
     CONST_SPEED_BASETX100 = "BASETX100"
     
     CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
@@ -94,6 +93,8 @@ class NUNSPort(NURESTObject):
     
     CONST_NAT_TRAVERSAL_FULL_NAT = "FULL_NAT"
     
+    CONST_SPEED_BASET10 = "BASET10"
+    
     CONST_PERMITTED_ACTION_READ = "READ"
     
     CONST_PERMITTED_ACTION_USE = "USE"
@@ -142,6 +143,7 @@ class NUNSPort(NURESTObject):
         self._template_id = None
         self._permitted_action = None
         self._description = None
+        self._shunt_port = None
         self._physical_name = None
         self._enable_nat_probes = None
         self._entity_scope = None
@@ -163,11 +165,12 @@ class NUNSPort(NURESTObject):
         self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="shunt_port", remote_name="shuntPort", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="physical_name", remote_name="physicalName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="enable_nat_probes", remote_name="enableNATProbes", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'NETWORK'])
-        self.expose_attribute(local_name="speed", remote_name="speed", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTONEGOTIATE', u'BASE10', u'BASET1000', u'BASETX100', u'BASEX10G'])
+        self.expose_attribute(local_name="speed", remote_name="speed", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTONEGOTIATE', u'BASET10', u'BASET1000', u'BASETX100', u'BASEX10G'])
         self.expose_attribute(local_name="traffic_through_ubr_only", remote_name="TrafficThroughUBROnly", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
@@ -220,7 +223,7 @@ class NUNSPort(NURESTObject):
         """ Get nat_traversal value.
 
             Notes:
-                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet.
+                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet. (This field is deprecated in 5.0)
 
                 
                 This attribute is named `NATTraversal` in VSD API.
@@ -233,7 +236,7 @@ class NUNSPort(NURESTObject):
         """ Set nat_traversal value.
 
             Notes:
-                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet.
+                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet. (This field is deprecated in 5.0)
 
                 
                 This attribute is named `NATTraversal` in VSD API.
@@ -247,7 +250,7 @@ class NUNSPort(NURESTObject):
         """ Get vlan_range value.
 
             Notes:
-                VLAN Range of the Port.  Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4095.
+                VLAN Range of the Port. Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4094.
 
                 
                 This attribute is named `VLANRange` in VSD API.
@@ -260,7 +263,7 @@ class NUNSPort(NURESTObject):
         """ Set vlan_range value.
 
             Notes:
-                VLAN Range of the Port.  Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4095.
+                VLAN Range of the Port. Format must conform to a-b,c,d-f where a,b,c,d,f are integers between 0 and 4094.
 
                 
                 This attribute is named `VLANRange` in VSD API.
@@ -351,7 +354,7 @@ class NUNSPort(NURESTObject):
         """ Get permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this NSG Port.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -364,7 +367,7 @@ class NUNSPort(NURESTObject):
         """ Set permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this NSG Port.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -396,6 +399,33 @@ class NUNSPort(NURESTObject):
         self._description = value
 
     
+    @property
+    def shunt_port(self):
+        """ Get shunt_port value.
+
+            Notes:
+                Identifies a Port instance on which a VLAN is shunted.  Ports of type Network are the only one that supports being in Shunt mode. Shunted ports are only relevant when NSGs are in redundant mode.
+
+                
+                This attribute is named `shuntPort` in VSD API.
+                
+        """
+        return self._shunt_port
+
+    @shunt_port.setter
+    def shunt_port(self, value):
+        """ Set shunt_port value.
+
+            Notes:
+                Identifies a Port instance on which a VLAN is shunted.  Ports of type Network are the only one that supports being in Shunt mode. Shunted ports are only relevant when NSGs are in redundant mode.
+
+                
+                This attribute is named `shuntPort` in VSD API.
+                
+        """
+        self._shunt_port = value
+
+    
     @property
     def physical_name(self):
         """ Get physical_name value.
@@ -559,7 +589,7 @@ class NUNSPort(NURESTObject):
         """ Get use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use user mnemonic of the NSG Port
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -572,7 +602,7 @@ class NUNSPort(NURESTObject):
         """ Set use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use user mnemonic of the NSG Port
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -613,7 +643,7 @@ class NUNSPort(NURESTObject):
         """ Get associated_egress_qos_policy_id value.
 
             Notes:
-                ID of the Egress QOS Policy associated with this Vlan.
+                ID of the Egress QoS Policy associated with this NSG Port.
 
                 
                 This attribute is named `associatedEgressQOSPolicyID` in VSD API.
@@ -626,7 +656,7 @@ class NUNSPort(NURESTObject):
         """ Set associated_egress_qos_policy_id value.
 
             Notes:
-                ID of the Egress QOS Policy associated with this Vlan.
+                ID of the Egress QoS Policy associated with this NSG Port.
 
                 
                 This attribute is named `associatedEgressQOSPolicyID` in VSD API.
