@@ -88,24 +88,24 @@ class NUVRSRedeploymentpolicy(NURESTObject):
         self._owner = None
         self._external_id = None
         
-        self.expose_attribute(local_name="al_ubr0_status_redeployment_enabled", remote_name="ALUbr0StatusRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="cpu_utilization_redeployment_enabled", remote_name="CPUUtilizationRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="cpu_utilization_threshold", remote_name="CPUUtilizationThreshold", attribute_type=float, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="vrs_corrective_action_delay", remote_name="VRSCorrectiveActionDelay", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="vrs_process_redeployment_enabled", remote_name="VRSProcessRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="vrsvsc_status_redeployment_enabled", remote_name="VRSVSCStatusRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="al_ubr0_status_redeployment_enabled", remote_name="ALUbr0StatusRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="cpu_utilization_redeployment_enabled", remote_name="CPUUtilizationRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="cpu_utilization_threshold", remote_name="CPUUtilizationThreshold", attribute_type=float, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="vrs_corrective_action_delay", remote_name="VRSCorrectiveActionDelay", attribute_type=int, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="vrs_process_redeployment_enabled", remote_name="VRSProcessRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="vrsvsc_status_redeployment_enabled", remote_name="VRSVSCStatusRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="redeployment_delay", remote_name="redeploymentDelay", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="memory_utilization_redeployment_enabled", remote_name="memoryUtilizationRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="memory_utilization_threshold", remote_name="memoryUtilizationThreshold", attribute_type=float, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="deployment_count_threshold", remote_name="deploymentCountThreshold", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="jesxmon_process_redeployment_enabled", remote_name="jesxmonProcessRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="redeployment_delay", remote_name="redeploymentDelay", attribute_type=int, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="memory_utilization_redeployment_enabled", remote_name="memoryUtilizationRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="memory_utilization_threshold", remote_name="memoryUtilizationThreshold", attribute_type=float, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="deployment_count_threshold", remote_name="deploymentCountThreshold", attribute_type=int, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="jesxmon_process_redeployment_enabled", remote_name="jesxmonProcessRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="log_disk_utilization_redeployment_enabled", remote_name="logDiskUtilizationRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="log_disk_utilization_threshold", remote_name="logDiskUtilizationThreshold", attribute_type=float, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="root_disk_utilization_redeployment_enabled", remote_name="rootDiskUtilizationRedeploymentEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="root_disk_utilization_threshold", remote_name="rootDiskUtilizationThreshold", attribute_type=float, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="log_disk_utilization_redeployment_enabled", remote_name="logDiskUtilizationRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="log_disk_utilization_threshold", remote_name="logDiskUtilizationThreshold", attribute_type=float, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="root_disk_utilization_redeployment_enabled", remote_name="rootDiskUtilizationRedeploymentEnabled", attribute_type=bool, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="root_disk_utilization_threshold", remote_name="rootDiskUtilizationThreshold", attribute_type=float, is_required=True, is_unique=False)
         self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
